@@ -26,23 +26,17 @@ PendulumRK4App <- function(verbose = FALSE) {
 
     rowvec <- vector("list")
     i <- 1
-    while (pendulum@state[3] <= 1000)    {
+    while (pendulum@state[3] <= 20)    {
         rowvec[[i]] <- list(state1 = pendulum@state[1], # angle
                             state2 = pendulum@state[2],      # derivative of the angle
                             state3 = pendulum@state[3])       # time
-        if (verbose)
-            cat(sprintf("state1=%12f state2=%12f state3=%12f \n",
-                        pendulum@state[1], pendulum@state[2], pendulum@state[3]))
         i <- i + 1
         pendulum <- step(pendulum)
     }
-    DTRK4 <- data.table::rbindlist(rowvec)
+    return(data.table::rbindlist(rowvec))
 
-    if (verbose) {
-    x11()
-    print(ggplot(DTRK4, aes(x = state3, y = state1)) + geom_line(col = "blue"))
-    x11()
-    print(ggplot(DTRK4, aes(x = state3, y = state2)) + geom_line(col = "red"))
-    # save(DTRK4, file = "./data/pendulumRK4_1e-1.rda")
-    }
 }
+
+
+solution <- PendulumRK4App()
+plot(solution)
